interface GroupData {
    id: string;
    chatId: string;
    name: string;
    owner: string;
    participants: Iterable<string>;
}
/**
 * This class allows access to the details of each group a {@link GroupRepository}
 * must be used to obtain instances of this class.
 */
export declare class Group {
    /** The unique id that identifies the group */
    readonly id: string;
    /** The unique id that identifies the group for chat */
    readonly chatId: string;
    /** The name of the group */
    readonly name: string;
    /** The user that owns the group */
    readonly owner: string;
    /**
     * A list of the users that belong to the group
     */
    readonly participants: readonly string[];
    /** @ignore */
    static of({ id, chatId, name, owner, participants }: GroupData): Group;
    private constructor();
    /**
     * Creates a new Group object with the provided parameter changed
     */
    with({ name, participants }?: {
        name?: string | undefined;
        participants?: readonly string[] | undefined;
    }): Group;
    /**
     * Creates a new Group object adding the provided participants
     */
    plusParticipants(...participants: string[]): Group;
    /**
     * Creates a new Group object removing the provided participants
     */
    minusParticipants(...participants: string[]): Group;
}
export {};
