import { MeetingParticipant } from './MeetingParticipant';
export interface MeetingParameters {
    id: string;
    name: string;
    creator: string;
    participants: Iterable<MeetingParticipant>;
    language: string;
    validSince: number;
    validUntil: number;
    url: string;
    phone: string;
    record: boolean;
    isPasswordProtected: boolean;
}
/**
 * Represents a meeting. This class is immutable.
 * All the properties are readonly and must never be changed.
 * Instances of this class are usually obtained using {@link MeetingManager}
 */
export declare class Meeting {
    /** The ID of the meeting */
    readonly id: string;
    /** The name for the meeting */
    readonly name: string;
    /** The address of the meeting creator */
    readonly creator: string;
    /** The people participating in the meeting */
    readonly participants: readonly MeetingParticipant[];
    /** The language for the meeting */
    readonly language: string;
    /** The starting time for the meeting */
    readonly validSince: number;
    /** The ending time for the meeting */
    readonly validUntil: number;
    /** The link to access to the meeting */
    readonly url: string;
    /** Who will be called to access to the meeting */
    readonly phone: string;
    /** Indicates if the meeting will be recorded */
    readonly record: boolean;
    /** Is this meeting password protected */
    readonly isPasswordProtected: boolean;
    /** @ignore */
    constructor(data: MeetingParameters);
    /**
     * Checks if the participant in a meeting is online
     */
    isOnline(): boolean;
    /**
     * Returns a new meeting with the provided values changed
     */
    with({ name, participants, language, validSince, validUntil, url, phone, record, isPasswordProtected, }?: Partial<Omit<MeetingParameters, 'creator' | 'id'>>): Meeting;
}
