import { MeetingService } from '../wac-proxy/wac-stack/MeetingService';
import { Meeting } from './Meeting';
import { MeetingParticipant } from './MeetingParticipant';
export interface MeetingData {
    name: string;
    validSince: number;
    validUntil: number;
    participants: Iterable<MeetingParticipant>;
    record: boolean;
    password?: string;
}
/**
 * An instance of this class is obtained by calling the {@link Session#getMeetingManager}
 * method of {@link Session} and must not be directly instantiated.
 */
export declare class MeetingManager {
    private initLock;
    private meetingService;
    private meetingsSubject;
    /** Retrieves a list with the available meetings */
    readonly meetings$: import("rxjs").Observable<readonly Meeting[]>;
    /** @ignore */
    constructor(meetingService: MeetingService);
    /** @ignore */
    init(): Promise<void>;
    /** @ignore */
    uninit(): Promise<void>;
    /**
     * Retrieves a meeting with the following ID
     * @param meetingId ID of the meeting to retrieve
     */
    getMeeting(meetingId: string): Promise<Meeting>;
    /**
     * Retrieves a meeting with the requested room ID
     * @param id ID of room associated with the meeting to retrieve
     */
    getMeetingByRoomId(id: string): Promise<Meeting | undefined>;
    /**
     * Creates a meeting
     * @param data
     * @param sendSms If true, an invitation for the meeting will be sent in an SMS by the server.
     * @return The just created meeting
     */
    createMeeting(data: MeetingData, sendSms?: boolean): Promise<Meeting>;
    /**
     * Updates a meeting
     * @param id
     * @param data
     * @param sendSms If true, an invitation for the meeting will be sent in an SMS by the server.
     */
    saveMeeting(id: string, data: MeetingData, sendSms?: boolean): Promise<Meeting>;
    /**
     * Removes a meeting given its ID
     * @param meeting
     * @param meeting.id
     */
    deleteMeeting(id: string): Promise<void>;
    private onMeeting;
    private onMeetingDelete;
    private notifyMeeting;
}
