import { MediaTypes } from '../../../../types';
import { ServerAPI } from './ServerAPI';
export interface AttendedTransferResponseData {
    requestID: string;
    answer: string;
    payload: {
        uuid: string;
        transferee: string;
        transferor: string;
        target: string;
        roomId: string;
        queryRoom: {
            queryRoom: {
                acl: Array<{
                    username: string;
                    token: string;
                }>;
                ice: Array<{
                    urls: string;
                }>;
                owner: string;
                record: boolean;
                roomId: string;
                server: Array<{
                    http: string;
                    https: string;
                    ws: string;
                    wss: string;
                }>;
                sipUri: string;
                uuid: string;
            };
        };
    };
}
export declare class CallTransferAPI extends ServerAPI {
    /**
     * Try to perform an unattended call transfer
     * @param username who must be inserted in conference
     * @param roomId room identifier where invited user should join.
     * @param mediatypes MediaTypes included in the conference.
     * @return resolved with server response on success.
     */
    unattendedCallTransfer(id: string, username: string, roomId: string, mediatypes: MediaTypes): Promise<unknown>;
    /**
     * Accept performing the call transfer
     * @param callTransferID call transfer identifier
     * @return resolved with server response on success.
     */
    acceptCallTransfer(id: string, callTransferID: string): Promise<unknown>;
    /**
     * Try to perform an attended call transfer
     * @param target who must be inserted in conference.
     * @param roomId room identifier where invited user should join.
     * @param transferee user who will stay in the transferred conference
     * @return resolved with server response on success.
     */
    createAttendedCallTransfer(id: string, target: string, roomId: string, transferee: string): Promise<AttendedTransferResponseData>;
    /**
     * Accept performing the attended call transfer
     * @param target who must be inserted in conference.
     * @param roomId room identifier where invited user should join.
     * @return resolved with server response on success.
     */
    executeAttendedTransfer(id: string, target: string, roomId: string): Promise<AttendedTransferResponseData>;
    /**
     * Cancel performing the attended call transfer
     * @param target who must be inserted in conference.
     * @param roomId room identifier where invited user should join.
     * @return resolved with server response on success.
     */
    cancelAttendedTransfer(id: string, target: string, roomId: string): Promise<AttendedTransferResponseData>;
}
