import { MediaTypes } from '../../../../types';
import { ServerAPI } from './ServerAPI';
export declare class InvitesAPI extends ServerAPI {
    /**
     * Send an invitation to one room to the user with given username.
     * @throws {ErrorResponse} when server returns an error.
     * @param id invitation request ID.
     * @param from the user name that requested the invitation.
     * @param username user name to request invitation.
     * @param roomId room identifier where invited user should join.
     * @param mediatypes default mediatypes that invited peer should use.
     * @param requestId the ID of the request that generated this invitation.
     * @param context context information for agent assignment purposes
     * @return {Promise} resolved with server response on success.
     */
    invite(id: string, from: string, username: string, roomId: string, mediatypes: MediaTypes, requestId?: string, context?: {}): Promise<InviteResponse>;
    /**
     * Cancel a previous request.
     * @throws {ErrorResponse} when server returns an error.
     * @param id received invitation request Id.
     * @param from user name that requested the invitation
     * @param [error=487] rejection code to send
     */
    cancelInvitation(id: string, from: string, error?: number): void;
    /**
     * Accept a received invitation to join a room.
     * @throws {ErrorResponse} when server returns an error.
     * @param id invitation request ID.
     * @param from user name who send the invitation.
     * @return resolved with server response on success.
     */
    accept(id: string, from: string): Promise<unknown>;
    /**
     * Decline a received/sent invitation to join a room.
     * @throws {ErrorResponse} when server returns an error.
     * @param id invitation request ID.
     * @param from user name who send the invitation.
     * @param [error=603] rejection code to send
     * @return resoponse with server response on success.
     */
    decline(id: string, from: string, error?: number): Promise<unknown>;
    /**
     * Retrieve current invitations.
     * @throws {ErrorResponse} when server returns an error.
     * @param {string} id request Id.
     * @param {string} from user name that requests the invitations
     */
    getCurrentInvitations(id: string, from: string): Promise<CurrentInvitationsDto>;
}
interface InviteResponse {
    whoAccepted?: string;
}
interface CurrentInvitationsDto {
    payload?: {
        currentInvitations: unknown[];
    };
}
export {};
