import { SignalingClient } from './Client';
type Body = Record<string, any>;
export declare class ServerAPI {
    protected client: SignalingClient;
    constructor(client: SignalingClient);
    /**
     * Send a request to server with given data.
     * @throws {ErrorResponse} if server returns an error
     * @param type request type, i.e: 'createRoom', 'invitation',...
     * @param id request id
     * @param body requested body.
     * @param retry if specified and an id is provided, when an answer
     * is not received for this requested id, message will be send again periodically.
     * @return resolved with server response.
     */
    request(type: string, id: string, body: Body, retry?: number): Promise<Record<string, any>>;
    /**
     * Cancel a previous request.
     * @throws {ErrorResponse} if server returns an error
     * @param type response type, i.e: 'invitation',...
     * @param id request id
     */
    cancel(type: string, id: string, payload: Body): Promise<Record<string, any>>;
    /**
     * Send an answer to server with given data.
     * @throws {ErrorResponse} if server returns an error
     * @param type response type, i.e: 'invitation',...
     * @param id request id
     * @param payload response data.
     */
    answer(type: string, id: string, payload: Body): Promise<Record<string, any>>;
    answerWaitingResponse(type: string, id: string, payload: Record<string, any>): Promise<Record<string, any>>;
    waitAnserWithId(id: string): Promise<Record<string, any>>;
    waitAnswerWithInviteId(id: string): Promise<Record<string, any>>;
    cleanPendingWithId(id: string): void;
}
export {};
