type PayloadValidRawData = string[] | boolean | string;
type PayloadValidData = PayloadValidRawData | Record<string, PayloadValidRawData>;
interface RequestDto {
    requestID: string;
    request: string;
    payload?: Record<string, PayloadValidData>;
}
interface AnswerDto {
    requestID: string;
    answer: string;
}
interface CancelDto {
    requestID: string;
    cancel: string;
}
export type MuteEventDto = {
    type: 'event';
    payload: {
        eventName: 'mute';
        payload: {
            userId: string;
            roomId: string;
            muted: boolean;
        };
    };
};
export type MuteRequestEventDto = {
    type: 'event';
    payload: {
        eventName: 'mute-request';
        payload: {
            to: string;
            roomId: string;
            media: 'audio';
            muted: boolean;
        };
    };
};
export type MuteRequestDto = {
    requestID: string;
    request: 'mute';
    payload: {
        roomId: string;
        to: string;
        requestedBy: string;
        media: 'audio';
        muted: boolean;
    };
};
export type MessageDto = AnswerDto | CancelDto | MuteEventDto | MuteRequestDto | MuteRequestEventDto | RequestDto | {
    answer: 'ping';
};
interface IceServer {
    urls: string[] | string;
    username?: string;
    credential?: string;
}
interface RoomEndpoints {
    http: string;
    https: string;
    ws: string;
    wss: string;
}
export interface RoomDto {
    id: string;
    roomId: string;
    uuid: string;
    owner: string;
    record: boolean;
    number: string;
    sipUri: string;
    bitrate: number;
    serverUuid: string;
    timestamp: number;
    ice: IceServer[];
    server: Partial<RoomEndpoints>;
    token: string;
    participants: string[];
}
export {};
