import { BackgroundEffect } from '../../media/LocalMediaHandler';
interface Constraints {
    audio?: MediaTrackConstraints | boolean;
    video?: MediaTrackConstraints | boolean;
    screen?: MediaTrackConstraints | boolean;
}
export declare class MediaManager {
    #private;
    set backgroundEffect(effect: BackgroundEffect);
    get backgroundEffect(): BackgroundEffect;
    /**
     * Method that returns a {MediaStream} based on constraints provided
     * This method is needed for screen sharing when an unique stream that
     * contains audio, video and screen tracks must be obtained. Current implementation
     * has some limitations:
     *  - Require two video tracks (camera and screen) is not supported
     *  - Screen sharing is only supported on Chrome >= 72, Firefox >= 66 and Edge >= 17
     *
     * @param constraints audio camera and screen constraints
     * @return media stream with desired tracks
     */
    getUserMediaWithMediatypes(constraints?: Constraints): Promise<MediaStream>;
    private getUserMedia;
    private getDisplayMedia;
    private applyDefaultMediaTrackConstraints;
    private applyDefaultConstraints;
    private getVideoStream;
    private imageSegmenter;
    private loadSegmenter;
}
export {};
