import EventEmitter from 'eventemitter3';
import { WacRequest } from './WacRequest';
interface ParticipantDto {
    email?: string;
    phone?: string;
}
export interface MeetingDto {
    id: string;
    language: string;
    name: string;
    participants: readonly ParticipantDto[];
    phone: string;
    url: string;
    user: {
        username: string;
        domain: string;
    };
    validSince: number;
    validUntil: number;
    record: {
        type: 'all' | 'none';
    };
    isPasswordProtected: boolean;
}
export interface MeetingEditDto extends Pick<MeetingDto, 'name' | 'record' | 'validSince' | 'validUntil'> {
    participants: ReadonlyArray<ParticipantDto & {
        sendSMS?: boolean;
    }>;
    password: string | null;
}
export interface Meeting extends Omit<MeetingDto, 'record' | 'user'> {
    creator: string;
    record: boolean;
}
export interface MeetingEdit extends Pick<Meeting, 'name' | 'participants' | 'record' | 'validSince' | 'validUntil'> {
    password: string;
}
type Events = {
    create: [Meeting];
    delete: [Pick<Meeting, 'id'>];
    update: [Meeting];
};
export declare class MeetingService {
    emitter: EventEmitter<Events, any>;
    private wacRequest;
    constructor(wacRequest: WacRequest);
    private bindEventHandlers;
    private onEvent;
    get(): Promise<Meeting[]>;
    create(data: MeetingEdit, sendSms?: boolean): Promise<Meeting>;
    getById(meetingId: string): Promise<Meeting>;
    getByRoomId(id: string): Promise<Meeting>;
    update(meetingId: string, data: MeetingEdit, sendSms?: boolean): Promise<Meeting>;
    delete(meetingId: string): Promise<void>;
}
export {};
