import { Observable } from 'rxjs/internal/Observable';
import { WacRequest } from '../WacRequest';
import { PresenceDto, PresenceEvent } from './types';
type PresenceDtoUpdate = Pick<PresenceDto, 'activity' | 'avatar' | 'displayName' | 'mood' | 'note' | 'online'>;
export declare class PresenceService {
    private wacRequest;
    readonly event$: Observable<PresenceEvent>;
    constructor(wacRequest: WacRequest);
    /**
     * Get the presence associated with given address
     */
    get$(address: string): Observable<PresenceDto>;
    /**
     * Updates the presence associated with given address
     */
    update$(address: PresenceDto['address'], presence: Partial<PresenceDtoUpdate>): Observable<PresenceDto>;
    /**
     * Subscribe to user's presence updates
     */
    subscribeToPresence$(address: string): Observable<PresenceDto>;
    /**
     * Subscribe to presence updates for the specified addresses
     */
    subscribeToPresences$(addresses: string[]): Observable<PresenceDto[]>;
    /**
     * Unsubscribe from presence updates for the specified address
     */
    unsubscribeFromPresence$(address: string): Observable<void>;
}
export {};
