import {EventEmitter2} from 'eventemitter2';

/**
 * Provides access to methods for creating whiteboards. This class must not be
 * directly instantiated. It can be obtained using session#createWhiteboard or
 * listening to session#incommingWhiteBoard event.
 */
export class Whiteboard extends EventEmitter2 {
	/**
	 * Aspect ratio of the whiteboard.
	 */
	aspectRatio: number;

	/**
	 * Current background image shown.
	 */
	backgroundImage: Blob | string;

	/**
	 * Current background video shown.
	 */
	backgroundVideo: string;

	/**
	 * Color used for the shapes.
	 */
	color: string;

	/**
	 * Current height of the whiteboard.
	 */
	height: number;

	lineWidth: any;

	/**
	 * Gets the identities of the remote peers attached to this Whiteboard.
	 */
	remoteParticipants: string[];

	/**
	 * Current tool to use on user interaction.
	 */
	tool: string;

	/**
	 * Returns the current width of the whiteboard.
	 */
	width: number;

	/**
	 * Check if last undo call can be reverted.
	 */
	canRedo(): boolean;

	/**
	 * Check if last action can be reverted.
	 */
	canUndo(): boolean;

	/**
	 * Removes every shape from the whiteboard.
	 */
	clear(): undefined;

	/**
	 * Closes this whiteboard session.
	 */
	close(): Whiteboard;

	/**
	 * Init this whiteboard session.
	 */
	init(): Whiteboard;

	/**
	 * Revert last undo call.
	 */
	redo(): void;

	/**
	 * Allows to set the area that will be used as the canvas for the whiteboard.
	 */
	setArea(selector: HTMLElement | string | null): Whiteboard;

	/**
	 * Revert last change.
	 */
	undo(): void;
}
